# Weles [![Build Status](https://travis-ci.org/w4k2/weles.svg?branch=master)](https://travis-ci.org/w4k2/weles) [![Coverage Status](https://coveralls.io/repos/github/w4k2/weles/badge.svg?branch=master)](https://coveralls.io/github/w4k2/weles?branch=master)

Collection of various pattern recognition methods and experimental tools made by Machine Learning Group of Wrocław University of Science and Technology

## Current contents

- classifiers
  - `ExposerClassifier`
  - `LinearClassifier`
  - `SSGNB`
- ensemble
  - `Cluens`
  - `Geometron`
  - `GES`
  - `NURS`
  - `RandomSubspace`
  - `UMCE`
- meta
  - `PCASSE`
- optimizers
  - `RAO`
- statistics
  - `t_test_corrected`
  - `t_test_13`
  - `t_test_rel`
